Class: Google::Apis::GamesV1::Application

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

The Application resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Application

Returns a new instance of Application.



502
503
504
# File 'lib/google/apis/games_v1/classes.rb', line 502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#achievement_countFixnum

The number of achievements visible to the currently authenticated player. Corresponds to the JSON property achievement_count

Returns:

  • (Fixnum)


438
439
440
# File 'lib/google/apis/games_v1/classes.rb', line 438

def achievement_count
  @achievement_count
end

#assetsArray<Google::Apis::GamesV1::ImageAsset>

The assets of the application. Corresponds to the JSON property assets



443
444
445
# File 'lib/google/apis/games_v1/classes.rb', line 443

def assets
  @assets
end

#authorString

The author of the application. Corresponds to the JSON property author

Returns:

  • (String)


448
449
450
# File 'lib/google/apis/games_v1/classes.rb', line 448

def author
  @author
end

#categoryGoogle::Apis::GamesV1::ApplicationCategory

An application category object. Corresponds to the JSON property category



453
454
455
# File 'lib/google/apis/games_v1/classes.rb', line 453

def category
  @category
end

#descriptionString

The description of the application. Corresponds to the JSON property description

Returns:

  • (String)


458
459
460
# File 'lib/google/apis/games_v1/classes.rb', line 458

def description
  @description
end

#enabled_featuresArray<String>

A list of features that have been enabled for the application. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


463
464
465
# File 'lib/google/apis/games_v1/classes.rb', line 463

def enabled_features
  @enabled_features
end

#idString

The ID of the application. Corresponds to the JSON property id

Returns:

  • (String)


468
469
470
# File 'lib/google/apis/games_v1/classes.rb', line 468

def id
  @id
end

#instancesArray<Google::Apis::GamesV1::Instance>

The instances of the application. Corresponds to the JSON property instances



473
474
475
# File 'lib/google/apis/games_v1/classes.rb', line 473

def instances
  @instances
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#application. Corresponds to the JSON property kind

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/games_v1/classes.rb', line 479

def kind
  @kind
end

#last_updated_timestampFixnum

The last updated timestamp of the application. Corresponds to the JSON property lastUpdatedTimestamp

Returns:

  • (Fixnum)


484
485
486
# File 'lib/google/apis/games_v1/classes.rb', line 484

def last_updated_timestamp
  @last_updated_timestamp
end

#leaderboard_countFixnum

The number of leaderboards visible to the currently authenticated player. Corresponds to the JSON property leaderboard_count

Returns:

  • (Fixnum)


489
490
491
# File 'lib/google/apis/games_v1/classes.rb', line 489

def leaderboard_count
  @leaderboard_count
end

#nameString

The name of the application. Corresponds to the JSON property name

Returns:

  • (String)


494
495
496
# File 'lib/google/apis/games_v1/classes.rb', line 494

def name
  @name
end

#theme_colorString

A hint to the client UI for what color to use as an app-themed color. The color is given as an RGB triplet (e.g. "E0E0E0"). Corresponds to the JSON property themeColor

Returns:

  • (String)


500
501
502
# File 'lib/google/apis/games_v1/classes.rb', line 500

def theme_color
  @theme_color
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/google/apis/games_v1/classes.rb', line 507

def update!(**args)
  @achievement_count = args[:achievement_count] if args.key?(:achievement_count)
  @assets = args[:assets] if args.key?(:assets)
  @author = args[:author] if args.key?(:author)
  @category = args[:category] if args.key?(:category)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @last_updated_timestamp = args[:last_updated_timestamp] if args.key?(:last_updated_timestamp)
  @leaderboard_count = args[:leaderboard_count] if args.key?(:leaderboard_count)
  @name = args[:name] if args.key?(:name)
  @theme_color = args[:theme_color] if args.key?(:theme_color)
end