Class: Google::Apis::GamesV1::BatchRecordEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

Request message for PlayerGameEvents.BatchRecordEvents Next ID: 7

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchRecordEventsRequest

Returns a new instance of BatchRecordEventsRequest.



647
648
649
# File 'lib/google/apis/games_v1/classes.rb', line 647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#droid_guard_blobString

Optional. The DroidGuard blob generated by the client. This is used to detect abuse signals from the devices Corresponds to the JSON property droidGuardBlob

Returns:

  • (String)


622
623
624
# File 'lib/google/apis/games_v1/classes.rb', line 622

def droid_guard_blob
  @droid_guard_blob
end

#eventsArray<Google::Apis::GamesV1::PlayerGameEvent>

Required. A list of player game events to be recorded. Maximum of 30 events per batch request. Corresponds to the JSON property events



628
629
630
# File 'lib/google/apis/games_v1/classes.rb', line 628

def events
  @events
end

#package_nameString

Required. Application package name (e.g., "com.example.game"). Corresponds to the JSON property packageName

Returns:

  • (String)


633
634
635
# File 'lib/google/apis/games_v1/classes.rb', line 633

def package_name
  @package_name
end

#request_timeString

Required. The time from the client when this specific batch of events was submitted. Corresponds to the JSON property requestTime

Returns:

  • (String)


639
640
641
# File 'lib/google/apis/games_v1/classes.rb', line 639

def request_time
  @request_time
end

#saltString

Optional. The salt used to generate content binding for the DroidGuard blob. This is used to prevent replay attacks. Corresponds to the JSON property salt

Returns:

  • (String)


645
646
647
# File 'lib/google/apis/games_v1/classes.rb', line 645

def salt
  @salt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



652
653
654
655
656
657
658
# File 'lib/google/apis/games_v1/classes.rb', line 652

def update!(**args)
  @droid_guard_blob = args[:droid_guard_blob] if args.key?(:droid_guard_blob)
  @events = args[:events] if args.key?(:events)
  @package_name = args[:package_name] if args.key?(:package_name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @salt = args[:salt] if args.key?(:salt)
end