Class: Google::Apis::GamesV1::CheckRevisionResponse
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::CheckRevisionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A third party checking a revision response.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The version of the API this client revision should use when calling API methods.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#revision_status ⇒ String
The result of the revision check.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckRevisionResponse
constructor
A new instance of CheckRevisionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckRevisionResponse
Returns a new instance of CheckRevisionResponse.
2845 2846 2847 |
# File 'lib/google/apis/games_v1/classes.rb', line 2845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The version of the API this client revision should use when calling API
methods.
Corresponds to the JSON property apiVersion
2832 2833 2834 |
# File 'lib/google/apis/games_v1/classes.rb', line 2832 def api_version @api_version end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#revisionCheckResponse.
Corresponds to the JSON property kind
2838 2839 2840 |
# File 'lib/google/apis/games_v1/classes.rb', line 2838 def kind @kind end |
#revision_status ⇒ String
The result of the revision check.
Corresponds to the JSON property revisionStatus
2843 2844 2845 |
# File 'lib/google/apis/games_v1/classes.rb', line 2843 def revision_status @revision_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2850 2851 2852 2853 2854 |
# File 'lib/google/apis/games_v1/classes.rb', line 2850 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @revision_status = args[:revision_status] if args.key?(:revision_status) end |