Class: Google::Apis::GamesV1::EventDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

An event definition resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventDefinition

Returns a new instance of EventDefinition.



869
870
871
# File 'lib/google/apis/games_v1/classes.rb', line 869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#child_eventsArray<Google::Apis::GamesV1::EventChild>

A list of events that are a child of this event. Corresponds to the JSON property childEvents



829
830
831
# File 'lib/google/apis/games_v1/classes.rb', line 829

def child_events
  @child_events
end

#descriptionString

Description of what this event represents. Corresponds to the JSON property description

Returns:

  • (String)


834
835
836
# File 'lib/google/apis/games_v1/classes.rb', line 834

def description
  @description
end

#display_nameString

The name to display for the event. Corresponds to the JSON property displayName

Returns:

  • (String)


839
840
841
# File 'lib/google/apis/games_v1/classes.rb', line 839

def display_name
  @display_name
end

#idString

The ID of the event. Corresponds to the JSON property id

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/games_v1/classes.rb', line 844

def id
  @id
end

#image_urlString

The base URL for the image that represents the event. Corresponds to the JSON property imageUrl

Returns:

  • (String)


849
850
851
# File 'lib/google/apis/games_v1/classes.rb', line 849

def image_url
  @image_url
end

#is_default_image_urlBoolean Also known as: is_default_image_url?

Indicates whether the icon image being returned is a default image, or is game- provided. Corresponds to the JSON property isDefaultImageUrl

Returns:

  • (Boolean)


855
856
857
# File 'lib/google/apis/games_v1/classes.rb', line 855

def is_default_image_url
  @is_default_image_url
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#eventDefinition. Corresponds to the JSON property kind

Returns:

  • (String)


862
863
864
# File 'lib/google/apis/games_v1/classes.rb', line 862

def kind
  @kind
end

#visibilityString

The visibility of event being tracked in this definition. Corresponds to the JSON property visibility

Returns:

  • (String)


867
868
869
# File 'lib/google/apis/games_v1/classes.rb', line 867

def visibility
  @visibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



874
875
876
877
878
879
880
881
882
883
# File 'lib/google/apis/games_v1/classes.rb', line 874

def update!(**args)
  @child_events = args[:child_events] if args.key?(:child_events)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @image_url = args[:image_url] if args.key?(:image_url)
  @is_default_image_url = args[:is_default_image_url] if args.key?(:is_default_image_url)
  @kind = args[:kind] if args.key?(:kind)
  @visibility = args[:visibility] if args.key?(:visibility)
end