Class: Google::Apis::GamesV1::EventRecordRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

An event period update resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventRecordRequest

Returns a new instance of EventRecordRequest.



1041
1042
1043
# File 'lib/google/apis/games_v1/classes.rb', line 1041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_time_millisFixnum

The current time when this update was sent, in milliseconds, since 1970 UTC ( Unix Epoch). Corresponds to the JSON property currentTimeMillis

Returns:

  • (Fixnum)


1023
1024
1025
# File 'lib/google/apis/games_v1/classes.rb', line 1023

def current_time_millis
  @current_time_millis
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#eventRecordRequest. Corresponds to the JSON property kind

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/games_v1/classes.rb', line 1029

def kind
  @kind
end

#request_idFixnum

The request ID used to identify this attempt to record events. Corresponds to the JSON property requestId

Returns:

  • (Fixnum)


1034
1035
1036
# File 'lib/google/apis/games_v1/classes.rb', line 1034

def request_id
  @request_id
end

#time_periodsArray<Google::Apis::GamesV1::EventPeriodUpdate>

A list of the time period updates being made in this request. Corresponds to the JSON property timePeriods



1039
1040
1041
# File 'lib/google/apis/games_v1/classes.rb', line 1039

def time_periods
  @time_periods
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1046
1047
1048
1049
1050
1051
# File 'lib/google/apis/games_v1/classes.rb', line 1046

def update!(**args)
  @current_time_millis = args[:current_time_millis] if args.key?(:current_time_millis)
  @kind = args[:kind] if args.key?(:kind)
  @request_id = args[:request_id] if args.key?(:request_id)
  @time_periods = args[:time_periods] if args.key?(:time_periods)
end