Class: Google::Apis::GamesV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

The Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



1362
1363
1364
# File 'lib/google/apis/games_v1/classes.rb', line 1362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acquisition_uriString

URI which shows where a user can acquire this instance. Corresponds to the JSON property acquisitionUri

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/games_v1/classes.rb', line 1317

def acquisition_uri
  @acquisition_uri
end

#android_instanceGoogle::Apis::GamesV1::InstanceAndroidDetails

The Android instance details resource. Corresponds to the JSON property androidInstance



1322
1323
1324
# File 'lib/google/apis/games_v1/classes.rb', line 1322

def android_instance
  @android_instance
end

#ios_instanceGoogle::Apis::GamesV1::InstanceIosDetails

The iOS details resource. Corresponds to the JSON property iosInstance



1327
1328
1329
# File 'lib/google/apis/games_v1/classes.rb', line 1327

def ios_instance
  @ios_instance
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#instance. Corresponds to the JSON property kind

Returns:

  • (String)


1333
1334
1335
# File 'lib/google/apis/games_v1/classes.rb', line 1333

def kind
  @kind
end

#nameString

Localized display name. Corresponds to the JSON property name

Returns:

  • (String)


1338
1339
1340
# File 'lib/google/apis/games_v1/classes.rb', line 1338

def name
  @name
end

#platform_typeString

The platform type. Corresponds to the JSON property platformType

Returns:

  • (String)


1343
1344
1345
# File 'lib/google/apis/games_v1/classes.rb', line 1343

def platform_type
  @platform_type
end

#realtime_playBoolean Also known as: realtime_play?

Flag to show if this game instance supports realtime play. Corresponds to the JSON property realtimePlay

Returns:

  • (Boolean)


1348
1349
1350
# File 'lib/google/apis/games_v1/classes.rb', line 1348

def realtime_play
  @realtime_play
end

#turn_based_playBoolean Also known as: turn_based_play?

Flag to show if this game instance supports turn based play. Corresponds to the JSON property turnBasedPlay

Returns:

  • (Boolean)


1354
1355
1356
# File 'lib/google/apis/games_v1/classes.rb', line 1354

def turn_based_play
  @turn_based_play
end

#web_instanceGoogle::Apis::GamesV1::InstanceWebDetails

The Web details resource. Corresponds to the JSON property webInstance



1360
1361
1362
# File 'lib/google/apis/games_v1/classes.rb', line 1360

def web_instance
  @web_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
# File 'lib/google/apis/games_v1/classes.rb', line 1367

def update!(**args)
  @acquisition_uri = args[:acquisition_uri] if args.key?(:acquisition_uri)
  @android_instance = args[:android_instance] if args.key?(:android_instance)
  @ios_instance = args[:ios_instance] if args.key?(:ios_instance)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @platform_type = args[:platform_type] if args.key?(:platform_type)
  @realtime_play = args[:realtime_play] if args.key?(:realtime_play)
  @turn_based_play = args[:turn_based_play] if args.key?(:turn_based_play)
  @web_instance = args[:web_instance] if args.key?(:web_instance)
end