Class: Google::Apis::GamesV1::InstanceAndroidDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

The Android instance details resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAndroidDetails

Returns a new instance of InstanceAndroidDetails.



1407
1408
1409
# File 'lib/google/apis/games_v1/classes.rb', line 1407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_piracy_checkBoolean Also known as: enable_piracy_check?

Flag indicating whether the anti-piracy check is enabled. Corresponds to the JSON property enablePiracyCheck

Returns:

  • (Boolean)


1387
1388
1389
# File 'lib/google/apis/games_v1/classes.rb', line 1387

def enable_piracy_check
  @enable_piracy_check
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#instanceAndroidDetails. Corresponds to the JSON property kind

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/games_v1/classes.rb', line 1394

def kind
  @kind
end

#package_nameString

Android package name which maps to Google Play URL. Corresponds to the JSON property packageName

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/games_v1/classes.rb', line 1399

def package_name
  @package_name
end

#preferredBoolean Also known as: preferred?

Indicates that this instance is the default for new installations. Corresponds to the JSON property preferred

Returns:

  • (Boolean)


1404
1405
1406
# File 'lib/google/apis/games_v1/classes.rb', line 1404

def preferred
  @preferred
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1412
1413
1414
1415
1416
1417
# File 'lib/google/apis/games_v1/classes.rb', line 1412

def update!(**args)
  @enable_piracy_check = args[:enable_piracy_check] if args.key?(:enable_piracy_check)
  @kind = args[:kind] if args.key?(:kind)
  @package_name = args[:package_name] if args.key?(:package_name)
  @preferred = args[:preferred] if args.key?(:preferred)
end