Class: Google::Apis::GamesV1::Leaderboard
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::Leaderboard
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
The Leaderboard resource.
Instance Attribute Summary collapse
-
#icon_url ⇒ String
The icon for the leaderboard.
-
#id ⇒ String
The leaderboard ID.
-
#is_icon_url_default ⇒ Boolean
(also: #is_icon_url_default?)
Indicates whether the icon image being returned is a default image, or is game- provided.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#name ⇒ String
The name of the leaderboard.
-
#order ⇒ String
How scores are ordered.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Leaderboard
constructor
A new instance of Leaderboard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Leaderboard
Returns a new instance of Leaderboard.
1552 1553 1554 |
# File 'lib/google/apis/games_v1/classes.rb', line 1552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#icon_url ⇒ String
The icon for the leaderboard.
Corresponds to the JSON property iconUrl
1522 1523 1524 |
# File 'lib/google/apis/games_v1/classes.rb', line 1522 def icon_url @icon_url end |
#id ⇒ String
The leaderboard ID.
Corresponds to the JSON property id
1527 1528 1529 |
# File 'lib/google/apis/games_v1/classes.rb', line 1527 def id @id end |
#is_icon_url_default ⇒ Boolean Also known as: is_icon_url_default?
Indicates whether the icon image being returned is a default image, or is game-
provided.
Corresponds to the JSON property isIconUrlDefault
1533 1534 1535 |
# File 'lib/google/apis/games_v1/classes.rb', line 1533 def is_icon_url_default @is_icon_url_default end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#leaderboard.
Corresponds to the JSON property kind
1540 1541 1542 |
# File 'lib/google/apis/games_v1/classes.rb', line 1540 def kind @kind end |
#name ⇒ String
The name of the leaderboard.
Corresponds to the JSON property name
1545 1546 1547 |
# File 'lib/google/apis/games_v1/classes.rb', line 1545 def name @name end |
#order ⇒ String
How scores are ordered.
Corresponds to the JSON property order
1550 1551 1552 |
# File 'lib/google/apis/games_v1/classes.rb', line 1550 def order @order end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1557 1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/google/apis/games_v1/classes.rb', line 1557 def update!(**args) @icon_url = args[:icon_url] if args.key?(:icon_url) @id = args[:id] if args.key?(:id) @is_icon_url_default = args[:is_icon_url_default] if args.key?(:is_icon_url_default) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @order = args[:order] if args.key?(:order) end |