Class: Google::Apis::GamesV1::LeaderboardScoreRank
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::LeaderboardScoreRank
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A score rank in a leaderboard.
Instance Attribute Summary collapse
-
#formatted_num_scores ⇒ String
The number of scores in the leaderboard as a string.
-
#formatted_rank ⇒ String
The rank in the leaderboard as a string.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#num_scores ⇒ Fixnum
The number of scores in the leaderboard.
-
#rank ⇒ Fixnum
The rank in the leaderboard.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LeaderboardScoreRank
constructor
A new instance of LeaderboardScoreRank.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LeaderboardScoreRank
Returns a new instance of LeaderboardScoreRank.
1699 1700 1701 |
# File 'lib/google/apis/games_v1/classes.rb', line 1699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#formatted_num_scores ⇒ String
The number of scores in the leaderboard as a string.
Corresponds to the JSON property formattedNumScores
1676 1677 1678 |
# File 'lib/google/apis/games_v1/classes.rb', line 1676 def formatted_num_scores @formatted_num_scores end |
#formatted_rank ⇒ String
The rank in the leaderboard as a string.
Corresponds to the JSON property formattedRank
1681 1682 1683 |
# File 'lib/google/apis/games_v1/classes.rb', line 1681 def formatted_rank @formatted_rank end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#leaderboardScoreRank.
Corresponds to the JSON property kind
1687 1688 1689 |
# File 'lib/google/apis/games_v1/classes.rb', line 1687 def kind @kind end |
#num_scores ⇒ Fixnum
The number of scores in the leaderboard.
Corresponds to the JSON property numScores
1692 1693 1694 |
# File 'lib/google/apis/games_v1/classes.rb', line 1692 def num_scores @num_scores end |
#rank ⇒ Fixnum
The rank in the leaderboard.
Corresponds to the JSON property rank
1697 1698 1699 |
# File 'lib/google/apis/games_v1/classes.rb', line 1697 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1704 1705 1706 1707 1708 1709 1710 |
# File 'lib/google/apis/games_v1/classes.rb', line 1704 def update!(**args) @formatted_num_scores = args[:formatted_num_scores] if args.key?(:formatted_num_scores) @formatted_rank = args[:formatted_rank] if args.key?(:formatted_rank) @kind = args[:kind] if args.key?(:kind) @num_scores = args[:num_scores] if args.key?(:num_scores) @rank = args[:rank] if args.key?(:rank) end |