Class: Google::Apis::GamesV1::LinkPersonaRequest
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::LinkPersonaRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
Request to link an in-game account with a PGS principal (encoded in the session id).
Instance Attribute Summary collapse
-
#cardinality_constraint ⇒ String
Required.
-
#conflicting_links_resolution_policy ⇒ String
Required.
-
#expire_time ⇒ String
Input only.
-
#persona ⇒ String
Required.
-
#session_id ⇒ String
Required.
-
#token ⇒ String
Required.
-
#ttl ⇒ String
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkPersonaRequest
constructor
A new instance of LinkPersonaRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkPersonaRequest
Returns a new instance of LinkPersonaRequest.
1808 1809 1810 |
# File 'lib/google/apis/games_v1/classes.rb', line 1808 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cardinality_constraint ⇒ String
Required. Cardinality constraint to observe when linking a persona to a player
in the scope of a game.
Corresponds to the JSON property cardinalityConstraint
1772 1773 1774 |
# File 'lib/google/apis/games_v1/classes.rb', line 1772 def cardinality_constraint @cardinality_constraint end |
#conflicting_links_resolution_policy ⇒ String
Required. Resolution policy to apply when the linking of a persona to a player
would result in violating the specified cardinality constraint.
Corresponds to the JSON property conflictingLinksResolutionPolicy
1778 1779 1780 |
# File 'lib/google/apis/games_v1/classes.rb', line 1778 def conflicting_links_resolution_policy @conflicting_links_resolution_policy end |
#expire_time ⇒ String
Input only. Optional expiration time.
Corresponds to the JSON property expireTime
1783 1784 1785 |
# File 'lib/google/apis/games_v1/classes.rb', line 1783 def expire_time @expire_time end |
#persona ⇒ String
Required. Stable identifier of the in-game account. Please refrain from re-
using the same persona for different games.
Corresponds to the JSON property persona
1789 1790 1791 |
# File 'lib/google/apis/games_v1/classes.rb', line 1789 def persona @persona end |
#session_id ⇒ String
Required. Opaque server-generated string that encodes all the necessary
information to identify the PGS player / Google user and application.
Corresponds to the JSON property sessionId
1795 1796 1797 |
# File 'lib/google/apis/games_v1/classes.rb', line 1795 def session_id @session_id end |
#token ⇒ String
Required. Value of the token to create. Opaque to Play Games and assumed to be
non-stable (encrypted with key rotation).
Corresponds to the JSON property token
1801 1802 1803 |
# File 'lib/google/apis/games_v1/classes.rb', line 1801 def token @token end |
#ttl ⇒ String
Input only. Optional time-to-live.
Corresponds to the JSON property ttl
1806 1807 1808 |
# File 'lib/google/apis/games_v1/classes.rb', line 1806 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1813 1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/google/apis/games_v1/classes.rb', line 1813 def update!(**args) @cardinality_constraint = args[:cardinality_constraint] if args.key?(:cardinality_constraint) @conflicting_links_resolution_policy = args[:conflicting_links_resolution_policy] if args.key?(:conflicting_links_resolution_policy) @expire_time = args[:expire_time] if args.key?(:expire_time) @persona = args[:persona] if args.key?(:persona) @session_id = args[:session_id] if args.key?(:session_id) @token = args[:token] if args.key?(:token) @ttl = args[:ttl] if args.key?(:ttl) end |