Class: Google::Apis::GamesV1::ListPlayerLeaderboardScoreResponse
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::ListPlayerLeaderboardScoreResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A list of player leaderboard scores.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::GamesV1::PlayerLeaderboardScore>
The leaderboard scores.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#next_page_token ⇒ String
The pagination token for the next page of results.
-
#player ⇒ Google::Apis::GamesV1::Player
A Player resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPlayerLeaderboardScoreResponse
constructor
A new instance of ListPlayerLeaderboardScoreResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPlayerLeaderboardScoreResponse
Returns a new instance of ListPlayerLeaderboardScoreResponse.
2262 2263 2264 |
# File 'lib/google/apis/games_v1/classes.rb', line 2262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::GamesV1::PlayerLeaderboardScore>
The leaderboard scores.
Corresponds to the JSON property items
2244 2245 2246 |
# File 'lib/google/apis/games_v1/classes.rb', line 2244 def items @items end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#playerLeaderboardScoreListResponse.
Corresponds to the JSON property kind
2250 2251 2252 |
# File 'lib/google/apis/games_v1/classes.rb', line 2250 def kind @kind end |
#next_page_token ⇒ String
The pagination token for the next page of results.
Corresponds to the JSON property nextPageToken
2255 2256 2257 |
# File 'lib/google/apis/games_v1/classes.rb', line 2255 def next_page_token @next_page_token end |
#player ⇒ Google::Apis::GamesV1::Player
A Player resource.
Corresponds to the JSON property player
2260 2261 2262 |
# File 'lib/google/apis/games_v1/classes.rb', line 2260 def player @player end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2267 2268 2269 2270 2271 2272 |
# File 'lib/google/apis/games_v1/classes.rb', line 2267 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @player = args[:player] if args.key?(:player) end |