Class: Google::Apis::GamesV1::PlayerEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

An event status resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlayerEvent

Returns a new instance of PlayerEvent.



2138
2139
2140
# File 'lib/google/apis/games_v1/classes.rb', line 2138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#definition_idString

The ID of the event definition. Corresponds to the JSON property definitionId

Returns:

  • (String)


2113
2114
2115
# File 'lib/google/apis/games_v1/classes.rb', line 2113

def definition_id
  @definition_id
end

#formatted_num_eventsString

The current number of times this event has occurred, as a string. The formatting of this string depends on the configuration of your event in the Play Games Developer Console. Corresponds to the JSON property formattedNumEvents

Returns:

  • (String)


2120
2121
2122
# File 'lib/google/apis/games_v1/classes.rb', line 2120

def formatted_num_events
  @formatted_num_events
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#playerEvent. Corresponds to the JSON property kind

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/games_v1/classes.rb', line 2126

def kind
  @kind
end

#num_eventsFixnum

The current number of times this event has occurred. Corresponds to the JSON property numEvents

Returns:

  • (Fixnum)


2131
2132
2133
# File 'lib/google/apis/games_v1/classes.rb', line 2131

def num_events
  @num_events
end

#player_idString

The ID of the player. Corresponds to the JSON property playerId

Returns:

  • (String)


2136
2137
2138
# File 'lib/google/apis/games_v1/classes.rb', line 2136

def player_id
  @player_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2143
2144
2145
2146
2147
2148
2149
# File 'lib/google/apis/games_v1/classes.rb', line 2143

def update!(**args)
  @definition_id = args[:definition_id] if args.key?(:definition_id)
  @formatted_num_events = args[:formatted_num_events] if args.key?(:formatted_num_events)
  @kind = args[:kind] if args.key?(:kind)
  @num_events = args[:num_events] if args.key?(:num_events)
  @player_id = args[:player_id] if args.key?(:player_id)
end