Class: Google::Apis::GamesV1::PlayerScoreResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

A list of leaderboard entry resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlayerScoreResponse

Returns a new instance of PlayerScoreResponse.



2566
2567
2568
# File 'lib/google/apis/games_v1/classes.rb', line 2566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#beaten_score_time_spansArray<String>

The time spans where the submitted score is better than the existing score for that time span. Corresponds to the JSON property beatenScoreTimeSpans

Returns:

  • (Array<String>)


2535
2536
2537
# File 'lib/google/apis/games_v1/classes.rb', line 2535

def beaten_score_time_spans
  @beaten_score_time_spans
end

#formatted_scoreString

The formatted value of the submitted score. Corresponds to the JSON property formattedScore

Returns:

  • (String)


2540
2541
2542
# File 'lib/google/apis/games_v1/classes.rb', line 2540

def formatted_score
  @formatted_score
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#playerScoreResponse. Corresponds to the JSON property kind

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/games_v1/classes.rb', line 2546

def kind
  @kind
end

#leaderboard_idString

The leaderboard ID that this score was submitted to. Corresponds to the JSON property leaderboardId

Returns:

  • (String)


2551
2552
2553
# File 'lib/google/apis/games_v1/classes.rb', line 2551

def leaderboard_id
  @leaderboard_id
end

#score_tagString

Additional information about this score. Values will contain no more than 64 URI-safe characters as defined by section 2.3 of RFC 3986. Corresponds to the JSON property scoreTag

Returns:

  • (String)


2557
2558
2559
# File 'lib/google/apis/games_v1/classes.rb', line 2557

def score_tag
  @score_tag
end

#unbeaten_scoresArray<Google::Apis::GamesV1::PlayerScore>

The scores in time spans that have not been beaten. As an example, the submitted score may be better than the player's DAILY score, but not better than the player's scores for the WEEKLY or ALL_TIME time spans. Corresponds to the JSON property unbeatenScores



2564
2565
2566
# File 'lib/google/apis/games_v1/classes.rb', line 2564

def unbeaten_scores
  @unbeaten_scores
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/google/apis/games_v1/classes.rb', line 2571

def update!(**args)
  @beaten_score_time_spans = args[:beaten_score_time_spans] if args.key?(:beaten_score_time_spans)
  @formatted_score = args[:formatted_score] if args.key?(:formatted_score)
  @kind = args[:kind] if args.key?(:kind)
  @leaderboard_id = args[:leaderboard_id] if args.key?(:leaderboard_id)
  @score_tag = args[:score_tag] if args.key?(:score_tag)
  @unbeaten_scores = args[:unbeaten_scores] if args.key?(:unbeaten_scores)
end