Class: Google::Apis::GamesV1::ResetPersonaRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

Request to remove all Recall tokens associated with a persona for an app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResetPersonaRequest

Returns a new instance of ResetPersonaRequest.



2573
2574
2575
# File 'lib/google/apis/games_v1/classes.rb', line 2573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#personaString

Value of the 'persona' field as it was provided by the client in LinkPersona RPC Corresponds to the JSON property persona

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/games_v1/classes.rb', line 2571

def persona
  @persona
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2578
2579
2580
# File 'lib/google/apis/games_v1/classes.rb', line 2578

def update!(**args)
  @persona = args[:persona] if args.key?(:persona)
end