Class: Google::Apis::GamesV1::RetrieveGamesPlayerTokensResponse
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::RetrieveGamesPlayerTokensResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A list of recall token data returned from the RetrieveGamesPlayerTokens RPC
Instance Attribute Summary collapse
-
#game_player_tokens ⇒ Array<Google::Apis::GamesV1::GamePlayerToken>
The requested applications along with the recall tokens for the player.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetrieveGamesPlayerTokensResponse
constructor
A new instance of RetrieveGamesPlayerTokensResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetrieveGamesPlayerTokensResponse
Returns a new instance of RetrieveGamesPlayerTokensResponse.
2795 2796 2797 |
# File 'lib/google/apis/games_v1/classes.rb', line 2795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#game_player_tokens ⇒ Array<Google::Apis::GamesV1::GamePlayerToken>
The requested applications along with the recall tokens for the player. If the
player does not have recall tokens for an application, that application is not
included in the response.
Corresponds to the JSON property gamePlayerTokens
2793 2794 2795 |
# File 'lib/google/apis/games_v1/classes.rb', line 2793 def game_player_tokens @game_player_tokens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2800 2801 2802 |
# File 'lib/google/apis/games_v1/classes.rb', line 2800 def update!(**args) @game_player_tokens = args[:game_player_tokens] if args.key?(:game_player_tokens) end |