Class: Google::Apis::GamesV1::Snapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

An snapshot object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Snapshot

Returns a new instance of Snapshot.



2995
2996
2997
# File 'lib/google/apis/games_v1/classes.rb', line 2995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cover_imageGoogle::Apis::GamesV1::SnapshotImage

An image of a snapshot. Corresponds to the JSON property coverImage



2939
2940
2941
# File 'lib/google/apis/games_v1/classes.rb', line 2939

def cover_image
  @cover_image
end

#descriptionString

The description of this snapshot. Corresponds to the JSON property description

Returns:

  • (String)


2944
2945
2946
# File 'lib/google/apis/games_v1/classes.rb', line 2944

def description
  @description
end

#drive_idString

The ID of the file underlying this snapshot in the Drive API. Only present if the snapshot is a view on a Drive file and the file is owned by the caller. Corresponds to the JSON property driveId

Returns:

  • (String)


2950
2951
2952
# File 'lib/google/apis/games_v1/classes.rb', line 2950

def drive_id
  @drive_id
end

#duration_millisFixnum

The duration associated with this snapshot, in millis. Corresponds to the JSON property durationMillis

Returns:

  • (Fixnum)


2955
2956
2957
# File 'lib/google/apis/games_v1/classes.rb', line 2955

def duration_millis
  @duration_millis
end

#idString

The ID of the snapshot. Corresponds to the JSON property id

Returns:

  • (String)


2960
2961
2962
# File 'lib/google/apis/games_v1/classes.rb', line 2960

def id
  @id
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#snapshot. Corresponds to the JSON property kind

Returns:

  • (String)


2966
2967
2968
# File 'lib/google/apis/games_v1/classes.rb', line 2966

def kind
  @kind
end

#last_modified_millisFixnum

The timestamp (in millis since Unix epoch) of the last modification to this snapshot. Corresponds to the JSON property lastModifiedMillis

Returns:

  • (Fixnum)


2972
2973
2974
# File 'lib/google/apis/games_v1/classes.rb', line 2972

def last_modified_millis
  @last_modified_millis
end

#progress_valueFixnum

The progress value (64-bit integer set by developer) associated with this snapshot. Corresponds to the JSON property progressValue

Returns:

  • (Fixnum)


2978
2979
2980
# File 'lib/google/apis/games_v1/classes.rb', line 2978

def progress_value
  @progress_value
end

#titleString

The title of this snapshot. Corresponds to the JSON property title

Returns:

  • (String)


2983
2984
2985
# File 'lib/google/apis/games_v1/classes.rb', line 2983

def title
  @title
end

#typeString

The type of this snapshot. Corresponds to the JSON property type

Returns:

  • (String)


2988
2989
2990
# File 'lib/google/apis/games_v1/classes.rb', line 2988

def type
  @type
end

#unique_nameString

The unique name provided when the snapshot was created. Corresponds to the JSON property uniqueName

Returns:

  • (String)


2993
2994
2995
# File 'lib/google/apis/games_v1/classes.rb', line 2993

def unique_name
  @unique_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/google/apis/games_v1/classes.rb', line 3000

def update!(**args)
  @cover_image = args[:cover_image] if args.key?(:cover_image)
  @description = args[:description] if args.key?(:description)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @duration_millis = args[:duration_millis] if args.key?(:duration_millis)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_millis = args[:last_modified_millis] if args.key?(:last_modified_millis)
  @progress_value = args[:progress_value] if args.key?(:progress_value)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
  @unique_name = args[:unique_name] if args.key?(:unique_name)
end