Class: Google::Apis::GamesV1::UnlinkPersonaRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

Request to remove a Recall token linking PGS principal and an in-game account

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnlinkPersonaRequest

Returns a new instance of UnlinkPersonaRequest.



3048
3049
3050
# File 'lib/google/apis/games_v1/classes.rb', line 3048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#personaString

Value of the 'persona' field as it was provided by the client in LinkPersona RPC Corresponds to the JSON property persona

Returns:

  • (String)


3035
3036
3037
# File 'lib/google/apis/games_v1/classes.rb', line 3035

def persona
  @persona
end

#session_idString

Required. Opaque server-generated string that encodes all the necessary information to identify the PGS player / Google user and application. Corresponds to the JSON property sessionId

Returns:

  • (String)


3041
3042
3043
# File 'lib/google/apis/games_v1/classes.rb', line 3041

def session_id
  @session_id
end

#tokenString

Value of the Recall token as it was provided by the client in LinkPersona RPC Corresponds to the JSON property token

Returns:

  • (String)


3046
3047
3048
# File 'lib/google/apis/games_v1/classes.rb', line 3046

def token
  @token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3053
3054
3055
3056
3057
# File 'lib/google/apis/games_v1/classes.rb', line 3053

def update!(**args)
  @persona = args[:persona] if args.key?(:persona)
  @session_id = args[:session_id] if args.key?(:session_id)
  @token = args[:token] if args.key?(:token)
end