Class: Google::Apis::GamesV1::UnlinkPersonaResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

Response for the UnlinkPersona RPC

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnlinkPersonaResponse

Returns a new instance of UnlinkPersonaResponse.



3072
3073
3074
# File 'lib/google/apis/games_v1/classes.rb', line 3072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#unlinkedBoolean Also known as: unlinked?

Required. Whether a Recall token specified by the request was deleted. Can be ' false' when there were no Recall tokens satisfied the criteria from the request. Corresponds to the JSON property unlinked

Returns:

  • (Boolean)


3069
3070
3071
# File 'lib/google/apis/games_v1/classes.rb', line 3069

def unlinked
  @unlinked
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3077
3078
3079
# File 'lib/google/apis/games_v1/classes.rb', line 3077

def update!(**args)
  @unlinked = args[:unlinked] if args.key?(:unlinked)
end