Class: Google::Apis::GamesV1::Application
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::Application
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
The Application resource.
Instance Attribute Summary collapse
-
#achievement_count ⇒ Fixnum
The number of achievements visible to the currently authenticated player.
-
#assets ⇒ Array<Google::Apis::GamesV1::ImageAsset>
The assets of the application.
-
#author ⇒ String
The author of the application.
-
#category ⇒ Google::Apis::GamesV1::ApplicationCategory
An application category object.
-
#description ⇒ String
The description of the application.
-
#enabled_features ⇒ Array<String>
A list of features that have been enabled for the application.
-
#id ⇒ String
The ID of the application.
-
#instances ⇒ Array<Google::Apis::GamesV1::Instance>
The instances of the application.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#last_updated_timestamp ⇒ Fixnum
The last updated timestamp of the application.
-
#leaderboard_count ⇒ Fixnum
The number of leaderboards visible to the currently authenticated player.
-
#name ⇒ String
The name of the application.
-
#theme_color ⇒ String
A hint to the client UI for what color to use as an app-themed color.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Application
constructor
A new instance of Application.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Application
Returns a new instance of Application.
502 503 504 |
# File 'lib/google/apis/games_v1/classes.rb', line 502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#achievement_count ⇒ Fixnum
The number of achievements visible to the currently authenticated player.
Corresponds to the JSON property achievement_count
438 439 440 |
# File 'lib/google/apis/games_v1/classes.rb', line 438 def achievement_count @achievement_count end |
#assets ⇒ Array<Google::Apis::GamesV1::ImageAsset>
The assets of the application.
Corresponds to the JSON property assets
443 444 445 |
# File 'lib/google/apis/games_v1/classes.rb', line 443 def assets @assets end |
#author ⇒ String
The author of the application.
Corresponds to the JSON property author
448 449 450 |
# File 'lib/google/apis/games_v1/classes.rb', line 448 def @author end |
#category ⇒ Google::Apis::GamesV1::ApplicationCategory
An application category object.
Corresponds to the JSON property category
453 454 455 |
# File 'lib/google/apis/games_v1/classes.rb', line 453 def category @category end |
#description ⇒ String
The description of the application.
Corresponds to the JSON property description
458 459 460 |
# File 'lib/google/apis/games_v1/classes.rb', line 458 def description @description end |
#enabled_features ⇒ Array<String>
A list of features that have been enabled for the application.
Corresponds to the JSON property enabledFeatures
463 464 465 |
# File 'lib/google/apis/games_v1/classes.rb', line 463 def enabled_features @enabled_features end |
#id ⇒ String
The ID of the application.
Corresponds to the JSON property id
468 469 470 |
# File 'lib/google/apis/games_v1/classes.rb', line 468 def id @id end |
#instances ⇒ Array<Google::Apis::GamesV1::Instance>
The instances of the application.
Corresponds to the JSON property instances
473 474 475 |
# File 'lib/google/apis/games_v1/classes.rb', line 473 def instances @instances end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#application.
Corresponds to the JSON property kind
479 480 481 |
# File 'lib/google/apis/games_v1/classes.rb', line 479 def kind @kind end |
#last_updated_timestamp ⇒ Fixnum
The last updated timestamp of the application.
Corresponds to the JSON property lastUpdatedTimestamp
484 485 486 |
# File 'lib/google/apis/games_v1/classes.rb', line 484 def @last_updated_timestamp end |
#leaderboard_count ⇒ Fixnum
The number of leaderboards visible to the currently authenticated player.
Corresponds to the JSON property leaderboard_count
489 490 491 |
# File 'lib/google/apis/games_v1/classes.rb', line 489 def leaderboard_count @leaderboard_count end |
#name ⇒ String
The name of the application.
Corresponds to the JSON property name
494 495 496 |
# File 'lib/google/apis/games_v1/classes.rb', line 494 def name @name end |
#theme_color ⇒ String
A hint to the client UI for what color to use as an app-themed color. The
color is given as an RGB triplet (e.g. "E0E0E0").
Corresponds to the JSON property themeColor
500 501 502 |
# File 'lib/google/apis/games_v1/classes.rb', line 500 def theme_color @theme_color end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/google/apis/games_v1/classes.rb', line 507 def update!(**args) @achievement_count = args[:achievement_count] if args.key?(:achievement_count) @assets = args[:assets] if args.key?(:assets) @author = args[:author] if args.key?(:author) @category = args[:category] if args.key?(:category) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @last_updated_timestamp = args[:last_updated_timestamp] if args.key?(:last_updated_timestamp) @leaderboard_count = args[:leaderboard_count] if args.key?(:leaderboard_count) @name = args[:name] if args.key?(:name) @theme_color = args[:theme_color] if args.key?(:theme_color) end |