Class: Google::Apis::GamesV1::ApplicationVerifyResponse
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::ApplicationVerifyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A third party application verification response resource.
Instance Attribute Summary collapse
-
#alternate_player_id ⇒ String
An alternate ID that was once used for the player that was issued the auth token used in this request.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#player_id ⇒ String
The ID of the player that was issued the auth token used in this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApplicationVerifyResponse
constructor
A new instance of ApplicationVerifyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApplicationVerifyResponse
Returns a new instance of ApplicationVerifyResponse.
602 603 604 |
# File 'lib/google/apis/games_v1/classes.rb', line 602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_player_id ⇒ String
An alternate ID that was once used for the player that was issued the auth
token used in this request. (This field is not normally populated.)
Corresponds to the JSON property alternate_player_id
589 590 591 |
# File 'lib/google/apis/games_v1/classes.rb', line 589 def alternate_player_id @alternate_player_id end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#applicationVerifyResponse.
Corresponds to the JSON property kind
595 596 597 |
# File 'lib/google/apis/games_v1/classes.rb', line 595 def kind @kind end |
#player_id ⇒ String
The ID of the player that was issued the auth token used in this request.
Corresponds to the JSON property player_id
600 601 602 |
# File 'lib/google/apis/games_v1/classes.rb', line 600 def player_id @player_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
607 608 609 610 611 |
# File 'lib/google/apis/games_v1/classes.rb', line 607 def update!(**args) @alternate_player_id = args[:alternate_player_id] if args.key?(:alternate_player_id) @kind = args[:kind] if args.key?(:kind) @player_id = args[:player_id] if args.key?(:player_id) end |