Class: Google::Apis::GamesV1::GetMultipleApplicationPlayerIdsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

Response message for GetMultipleApplicationPlayerIds rpc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetMultipleApplicationPlayerIdsResponse

Returns a new instance of GetMultipleApplicationPlayerIdsResponse.



1189
1190
1191
# File 'lib/google/apis/games_v1/classes.rb', line 1189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#player_idsArray<Google::Apis::GamesV1::ApplicationPlayerId>

Output only. The requested applications along with the scoped ids for tha player, if that player has an id for the application. If not, the application is not included in the response. Corresponds to the JSON property playerIds



1187
1188
1189
# File 'lib/google/apis/games_v1/classes.rb', line 1187

def player_ids
  @player_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1194
1195
1196
# File 'lib/google/apis/games_v1/classes.rb', line 1194

def update!(**args)
  @player_ids = args[:player_ids] if args.key?(:player_ids)
end