Class: Google::Apis::GamesV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb

Overview

The Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



1295
1296
1297
# File 'lib/google/apis/games_v1/classes.rb', line 1295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acquisition_uriString

URI which shows where a user can acquire this instance. Corresponds to the JSON property acquisitionUri

Returns:

  • (String)


1250
1251
1252
# File 'lib/google/apis/games_v1/classes.rb', line 1250

def acquisition_uri
  @acquisition_uri
end

#android_instanceGoogle::Apis::GamesV1::InstanceAndroidDetails

The Android instance details resource. Corresponds to the JSON property androidInstance



1255
1256
1257
# File 'lib/google/apis/games_v1/classes.rb', line 1255

def android_instance
  @android_instance
end

#ios_instanceGoogle::Apis::GamesV1::InstanceIosDetails

The iOS details resource. Corresponds to the JSON property iosInstance



1260
1261
1262
# File 'lib/google/apis/games_v1/classes.rb', line 1260

def ios_instance
  @ios_instance
end

#kindString

Uniquely identifies the type of this resource. Value is always the fixed string games#instance. Corresponds to the JSON property kind

Returns:

  • (String)


1266
1267
1268
# File 'lib/google/apis/games_v1/classes.rb', line 1266

def kind
  @kind
end

#nameString

Localized display name. Corresponds to the JSON property name

Returns:

  • (String)


1271
1272
1273
# File 'lib/google/apis/games_v1/classes.rb', line 1271

def name
  @name
end

#platform_typeString

The platform type. Corresponds to the JSON property platformType

Returns:

  • (String)


1276
1277
1278
# File 'lib/google/apis/games_v1/classes.rb', line 1276

def platform_type
  @platform_type
end

#realtime_playBoolean Also known as: realtime_play?

Flag to show if this game instance supports realtime play. Corresponds to the JSON property realtimePlay

Returns:

  • (Boolean)


1281
1282
1283
# File 'lib/google/apis/games_v1/classes.rb', line 1281

def realtime_play
  @realtime_play
end

#turn_based_playBoolean Also known as: turn_based_play?

Flag to show if this game instance supports turn based play. Corresponds to the JSON property turnBasedPlay

Returns:

  • (Boolean)


1287
1288
1289
# File 'lib/google/apis/games_v1/classes.rb', line 1287

def turn_based_play
  @turn_based_play
end

#web_instanceGoogle::Apis::GamesV1::InstanceWebDetails

The Web details resource. Corresponds to the JSON property webInstance



1293
1294
1295
# File 'lib/google/apis/games_v1/classes.rb', line 1293

def web_instance
  @web_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
# File 'lib/google/apis/games_v1/classes.rb', line 1300

def update!(**args)
  @acquisition_uri = args[:acquisition_uri] if args.key?(:acquisition_uri)
  @android_instance = args[:android_instance] if args.key?(:android_instance)
  @ios_instance = args[:ios_instance] if args.key?(:ios_instance)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @platform_type = args[:platform_type] if args.key?(:platform_type)
  @realtime_play = args[:realtime_play] if args.key?(:realtime_play)
  @turn_based_play = args[:turn_based_play] if args.key?(:turn_based_play)
  @web_instance = args[:web_instance] if args.key?(:web_instance)
end