Class: Google::Apis::GamesV1::InstanceAndroidDetails
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::InstanceAndroidDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
The Android instance details resource.
Instance Attribute Summary collapse
-
#enable_piracy_check ⇒ Boolean
(also: #enable_piracy_check?)
Flag indicating whether the anti-piracy check is enabled.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#package_name ⇒ String
Android package name which maps to Google Play URL.
-
#preferred ⇒ Boolean
(also: #preferred?)
Indicates that this instance is the default for new installations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAndroidDetails
constructor
A new instance of InstanceAndroidDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAndroidDetails
Returns a new instance of InstanceAndroidDetails.
1340 1341 1342 |
# File 'lib/google/apis/games_v1/classes.rb', line 1340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_piracy_check ⇒ Boolean Also known as: enable_piracy_check?
Flag indicating whether the anti-piracy check is enabled.
Corresponds to the JSON property enablePiracyCheck
1320 1321 1322 |
# File 'lib/google/apis/games_v1/classes.rb', line 1320 def enable_piracy_check @enable_piracy_check end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#instanceAndroidDetails.
Corresponds to the JSON property kind
1327 1328 1329 |
# File 'lib/google/apis/games_v1/classes.rb', line 1327 def kind @kind end |
#package_name ⇒ String
Android package name which maps to Google Play URL.
Corresponds to the JSON property packageName
1332 1333 1334 |
# File 'lib/google/apis/games_v1/classes.rb', line 1332 def package_name @package_name end |
#preferred ⇒ Boolean Also known as: preferred?
Indicates that this instance is the default for new installations.
Corresponds to the JSON property preferred
1337 1338 1339 |
# File 'lib/google/apis/games_v1/classes.rb', line 1337 def preferred @preferred end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1345 1346 1347 1348 1349 1350 |
# File 'lib/google/apis/games_v1/classes.rb', line 1345 def update!(**args) @enable_piracy_check = args[:enable_piracy_check] if args.key?(:enable_piracy_check) @kind = args[:kind] if args.key?(:kind) @package_name = args[:package_name] if args.key?(:package_name) @preferred = args[:preferred] if args.key?(:preferred) end |