Class: Google::Apis::GamesV1::Player
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::Player
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A Player resource.
Defined Under Namespace
Classes: Name
Instance Attribute Summary collapse
-
#avatar_image_url ⇒ String
The base URL for the image that represents the player.
-
#banner_url_landscape ⇒ String
The url to the landscape mode player banner image.
-
#banner_url_portrait ⇒ String
The url to the portrait mode player banner image.
-
#display_name ⇒ String
The name to display for the player.
-
#experience_info ⇒ Google::Apis::GamesV1::PlayerExperienceInfo
1P/3P metadata about the player's experience.
-
#friend_status ⇒ String
The friend status of the given player, relative to the requester.
-
#game_player_id ⇒ String
Per-application unique player identifier.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#name ⇒ Google::Apis::GamesV1::Player::Name
A representation of the individual components of the name.
-
#original_player_id ⇒ String
The player ID that was used for this player the first time they signed into the game in question.
-
#player_id ⇒ String
The ID of the player.
-
#profile_settings ⇒ Google::Apis::GamesV1::ProfileSettings
Profile settings Corresponds to the JSON property
profileSettings. -
#title ⇒ String
The player's title rewarded for their game activities.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Player
constructor
A new instance of Player.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Player
Returns a new instance of Player.
1902 1903 1904 |
# File 'lib/google/apis/games_v1/classes.rb', line 1902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avatar_image_url ⇒ String
The base URL for the image that represents the player.
Corresponds to the JSON property avatarImageUrl
1835 1836 1837 |
# File 'lib/google/apis/games_v1/classes.rb', line 1835 def avatar_image_url @avatar_image_url end |
#banner_url_landscape ⇒ String
The url to the landscape mode player banner image.
Corresponds to the JSON property bannerUrlLandscape
1840 1841 1842 |
# File 'lib/google/apis/games_v1/classes.rb', line 1840 def @banner_url_landscape end |
#banner_url_portrait ⇒ String
The url to the portrait mode player banner image.
Corresponds to the JSON property bannerUrlPortrait
1845 1846 1847 |
# File 'lib/google/apis/games_v1/classes.rb', line 1845 def @banner_url_portrait end |
#display_name ⇒ String
The name to display for the player.
Corresponds to the JSON property displayName
1850 1851 1852 |
# File 'lib/google/apis/games_v1/classes.rb', line 1850 def display_name @display_name end |
#experience_info ⇒ Google::Apis::GamesV1::PlayerExperienceInfo
1P/3P metadata about the player's experience.
Corresponds to the JSON property experienceInfo
1855 1856 1857 |
# File 'lib/google/apis/games_v1/classes.rb', line 1855 def experience_info @experience_info end |
#friend_status ⇒ String
The friend status of the given player, relative to the requester. This is
unset if the player is not sharing their friends list with the game.
Corresponds to the JSON property friendStatus
1861 1862 1863 |
# File 'lib/google/apis/games_v1/classes.rb', line 1861 def friend_status @friend_status end |
#game_player_id ⇒ String
Per-application unique player identifier.
Corresponds to the JSON property gamePlayerId
1866 1867 1868 |
# File 'lib/google/apis/games_v1/classes.rb', line 1866 def game_player_id @game_player_id end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#player
Corresponds to the JSON property kind
1872 1873 1874 |
# File 'lib/google/apis/games_v1/classes.rb', line 1872 def kind @kind end |
#name ⇒ Google::Apis::GamesV1::Player::Name
A representation of the individual components of the name.
Corresponds to the JSON property name
1877 1878 1879 |
# File 'lib/google/apis/games_v1/classes.rb', line 1877 def name @name end |
#original_player_id ⇒ String
The player ID that was used for this player the first time they signed into
the game in question. This is only populated for calls to player.get for the
requesting player, only if the player ID has subsequently changed, and only to
clients that support remapping player IDs.
Corresponds to the JSON property originalPlayerId
1885 1886 1887 |
# File 'lib/google/apis/games_v1/classes.rb', line 1885 def original_player_id @original_player_id end |
#player_id ⇒ String
The ID of the player.
Corresponds to the JSON property playerId
1890 1891 1892 |
# File 'lib/google/apis/games_v1/classes.rb', line 1890 def player_id @player_id end |
#profile_settings ⇒ Google::Apis::GamesV1::ProfileSettings
Profile settings
Corresponds to the JSON property profileSettings
1895 1896 1897 |
# File 'lib/google/apis/games_v1/classes.rb', line 1895 def profile_settings @profile_settings end |
#title ⇒ String
The player's title rewarded for their game activities.
Corresponds to the JSON property title
1900 1901 1902 |
# File 'lib/google/apis/games_v1/classes.rb', line 1900 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/google/apis/games_v1/classes.rb', line 1907 def update!(**args) @avatar_image_url = args[:avatar_image_url] if args.key?(:avatar_image_url) @banner_url_landscape = args[:banner_url_landscape] if args.key?(:banner_url_landscape) @banner_url_portrait = args[:banner_url_portrait] if args.key?(:banner_url_portrait) @display_name = args[:display_name] if args.key?(:display_name) @experience_info = args[:experience_info] if args.key?(:experience_info) @friend_status = args[:friend_status] if args.key?(:friend_status) @game_player_id = args[:game_player_id] if args.key?(:game_player_id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @original_player_id = args[:original_player_id] if args.key?(:original_player_id) @player_id = args[:player_id] if args.key?(:player_id) @profile_settings = args[:profile_settings] if args.key?(:profile_settings) @title = args[:title] if args.key?(:title) end |