Class: Google::Apis::GamesV1::PlayerScoreResponse
- Inherits:
-
Object
- Object
- Google::Apis::GamesV1::PlayerScoreResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_v1/classes.rb,
lib/google/apis/games_v1/representations.rb,
lib/google/apis/games_v1/representations.rb
Overview
A list of leaderboard entry resources.
Instance Attribute Summary collapse
-
#beaten_score_time_spans ⇒ Array<String>
The time spans where the submitted score is better than the existing score for that time span.
-
#formatted_score ⇒ String
The formatted value of the submitted score.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#leaderboard_id ⇒ String
The leaderboard ID that this score was submitted to.
-
#score_tag ⇒ String
Additional information about this score.
-
#unbeaten_scores ⇒ Array<Google::Apis::GamesV1::PlayerScore>
The scores in time spans that have not been beaten.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlayerScoreResponse
constructor
A new instance of PlayerScoreResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlayerScoreResponse
Returns a new instance of PlayerScoreResponse.
2455 2456 2457 |
# File 'lib/google/apis/games_v1/classes.rb', line 2455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#beaten_score_time_spans ⇒ Array<String>
The time spans where the submitted score is better than the existing score for
that time span.
Corresponds to the JSON property beatenScoreTimeSpans
2424 2425 2426 |
# File 'lib/google/apis/games_v1/classes.rb', line 2424 def beaten_score_time_spans @beaten_score_time_spans end |
#formatted_score ⇒ String
The formatted value of the submitted score.
Corresponds to the JSON property formattedScore
2429 2430 2431 |
# File 'lib/google/apis/games_v1/classes.rb', line 2429 def formatted_score @formatted_score end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string games#playerScoreResponse.
Corresponds to the JSON property kind
2435 2436 2437 |
# File 'lib/google/apis/games_v1/classes.rb', line 2435 def kind @kind end |
#leaderboard_id ⇒ String
The leaderboard ID that this score was submitted to.
Corresponds to the JSON property leaderboardId
2440 2441 2442 |
# File 'lib/google/apis/games_v1/classes.rb', line 2440 def leaderboard_id @leaderboard_id end |
#score_tag ⇒ String
Additional information about this score. Values will contain no more than 64
URI-safe characters as defined by section 2.3 of RFC 3986.
Corresponds to the JSON property scoreTag
2446 2447 2448 |
# File 'lib/google/apis/games_v1/classes.rb', line 2446 def score_tag @score_tag end |
#unbeaten_scores ⇒ Array<Google::Apis::GamesV1::PlayerScore>
The scores in time spans that have not been beaten. As an example, the
submitted score may be better than the player's DAILY score, but not better
than the player's scores for the WEEKLY or ALL_TIME time spans.
Corresponds to the JSON property unbeatenScores
2453 2454 2455 |
# File 'lib/google/apis/games_v1/classes.rb', line 2453 def unbeaten_scores @unbeaten_scores end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/google/apis/games_v1/classes.rb', line 2460 def update!(**args) @beaten_score_time_spans = args[:beaten_score_time_spans] if args.key?(:beaten_score_time_spans) @formatted_score = args[:formatted_score] if args.key?(:formatted_score) @kind = args[:kind] if args.key?(:kind) @leaderboard_id = args[:leaderboard_id] if args.key?(:leaderboard_id) @score_tag = args[:score_tag] if args.key?(:score_tag) @unbeaten_scores = args[:unbeaten_scores] if args.key?(:unbeaten_scores) end |